@@ -77,12 +77,18 @@ class Project(SQLObject):
     
     @classmethod
     def getProject(cls, title):
+        assert title
         projects = list(Project.selectBy(title=title))
         if not projects:
             return Project(title=title)
         else:
             return projects[0]
 
+    def destroySelf(self):
+        for tl in self.task_lists:
+            tl.destroySelf()
+        SQLObject.destroySelf(self)
+
 class TaskListRole(SQLObject):
     _cacheValue = False
     username = StringCol(length=255)
@@ -443,6 +449,7 @@ class Task(SQLObject):
         return sorted(self.comments + list(self.versions), key=_by_date, reverse=True)
 
     def revertToDate(self, date):
+        """FIXME: this actually destroys data, stupidly.  Do not use it."""
         versions_in_future = []
         TaskVersion = Task.versions.versionClass
         last_good_version = TaskVersion.select(AND(TaskVersion.q.masterID==self.id, TaskVersion.q.dateArchived < date)).orderBy('dateArchived')[-1]
@@ -490,6 +497,15 @@ class Task(SQLObject):
 
         f.close()
 
+    @property
+    def long_title(self):
+        return "%s in %s/%s" % (self.title, self.task_list.project.title, self.task_list.title)
+
+    def destroySelf(self):
+        for version in self.versions:
+            version.destroySelf()
+        super(Task, self).destroySelf()
+
 def sortedTasks(allowed_tasks, this_level, sort_by, sort_order):
     def _cmp(x, y):
         try:
@@ -705,10 +721,16 @@ class TaskList(SQLObject):
     def destroySelf(self):
         for permission in self.permissions:
             permission.destroySelf()
+
+        for role in self.special_users:
+            role.destroySelf()
         
         for feature in self.features:
             feature.destroySelf()
 
+        for task in self.tasks:
+            task.destroySelf()
+
         super(TaskList, self).destroySelf()
 
 TaskVersion = Task.versions.versionClass
