@@ -73,7 +73,7 @@ class TestTaskListController(TestController):
         res.mustcontain("The new tl title")
 
         res = app.post(url_for(controller='project', action='initialize'),
-                       extra_environ={"HTTP_X_OPENPLANS_PROJECT":"differentproj"})
+                       extra_environ={"HTTP_X_OPENPLANS_PROJECT":"differentproj", "HTTP_X_OPENPLANS_TASKTRACKER_INITIALIZE" : 'True'})
 
         res = app.get(url_for(controller='tasklist'), extra_environ={"HTTP_X_OPENPLANS_PROJECT":"differentproj"})
         assert "The new tl title" not in res.body
@@ -248,17 +248,18 @@ class TestTaskListController(TestController):
         assert 'test locking' in res
 
     def test_initialized(self):
+        tt_unavailable_msg = 'TaskTracker is currently unavailable'
         app = self.getApp('admin')
 
         ### uninitialize the project
-        res = app.post(url_for(controller='project', action='uninitialize'))
+        res = app.post(url_for(controller='project', action='uninitialize'), extra_environ={"HTTP_X_OPENPLANS_TASKTRACKER_INITIALIZE" : 'True'})
         res.mustcontain("successfully uninitialized project")
         
         ### no mere member should be able to do anything
         app = self.getApp('member')
         res = app.get(url_for(controller='tasklist'))
         res = res.follow()
-        res.mustcontain("has not installed a task tracker.")
+        res.mustcontain(tt_unavailable_msg)
 
         ### not even initialize the project
         from tasktracker.lib.base import NotInitializedException
@@ -272,15 +273,15 @@ class TestTaskListController(TestController):
         app = self.getApp('admin')
         res = app.get(url_for(controller='tasklist'))
         res = res.follow()
-        res.mustcontain("has not installed a task tracker.")
+        res.mustcontain(tt_unavailable_msg)
 
-        ### but an admin can initialize the project
-        res = app.post(url_for(controller='project', action='initialize'))
+        ### but an admin can initialize the project (via opencore)
+        res = app.post(url_for(controller='project', action='initialize'), extra_environ={"HTTP_X_OPENPLANS_TASKTRACKER_INITIALIZE" : 'True'})
         res.mustcontain("successfully initialized project")
         
         ### and then can do things as normal
         res = app.get(url_for(controller='tasklist'))
-        res.mustcontain("Glossary")
+        res.mustcontain("Within a task list")
 
     def test_task_create(self):
         """Tests creating a new task"""
